package com.ruoyi.device.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.ShiroUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.device.mapper.RecordUseMapper;
import com.ruoyi.device.domain.RecordUse;
import com.ruoyi.device.service.IRecordUseService;
import com.ruoyi.common.core.text.Convert;

/**
 * 使用记录Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-05-19
 */
@Service
public class RecordUseServiceImpl implements IRecordUseService 
{
    @Autowired
    private RecordUseMapper recordUseMapper;

    /**
     * 查询使用记录
     * 
     * @param objId 使用记录主键
     * @return 使用记录
     */
    @Override
    public RecordUse selectRecordUseByObjId(Long objId)
    {
        return recordUseMapper.selectRecordUseByObjId(objId);
    }

    /**
     * 查询使用记录列表
     * 
     * @param recordUse 使用记录
     * @return 使用记录
     */
    @Override
    public List<RecordUse> selectRecordUseList(RecordUse recordUse)
    {
        return recordUseMapper.selectRecordUseList(recordUse);
    }

    /**
     * 新增使用记录
     * 
     * @param recordUse 使用记录
     * @return 结果
     */
    @Override
    public int insertRecordUse(RecordUse recordUse)
    {
        recordUse.setCreateTime(DateUtils.getNowDate());
        recordUse.setCreateBy(ShiroUtils.getLoginName());
        return recordUseMapper.insertRecordUse(recordUse);
    }

    /**
     * 修改使用记录
     * 
     * @param recordUse 使用记录
     * @return 结果
     */
    @Override
    public int updateRecordUse(RecordUse recordUse)
    {
        return recordUseMapper.updateRecordUse(recordUse);
    }

    /**
     * 批量删除使用记录
     * 
     * @param objIds 需要删除的使用记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordUseByObjIds(String objIds)
    {
        return recordUseMapper.deleteRecordUseByObjIds(Convert.toStrArray(objIds));
    }

    /**
     * 删除使用记录信息
     * 
     * @param objId 使用记录主键
     * @return 结果
     */
    @Override
    public int deleteRecordUseByObjId(Long objId)
    {
        return recordUseMapper.deleteRecordUseByObjId(objId);
    }
}
